@@ -6,13 +6,7 @@ class Mysql():
         self.login_table = login_table
         self.auth = auth
     
-    def run(self, sql, dict_cursor=False, disconnect = True):
-        try:
-            if self.connection.is_connected():
-                pass
-        except:
-            self.connect()
-            
+    def run(self, sql, dict_cursor=True):            
         cursor = self.connection.cursor(buffered=True, dictionary=dict_cursor)
         cursor.execute(sql)
         data = None
@@ -23,8 +17,6 @@ class Mysql():
         self.connection.commit()  
         cursor.close()
         
-        if disconnect:
-            self.disconnect()
         return data
 
     def connect(self):
